<p align="center">
<img src=".github/assets/icon.png" alt="https://github.com/m1stadev/PyIMG4" width=256px> 
</p>

<h1 align="center">
PyIMG4
</h1>
<p align="center">
  <a href="https://github.com/m1stadev/PyIMG4/blob/master/LICENSE">
    <image src="https://img.shields.io/github/license/m1stadev/PyIMG4">
  </a>
  <a href="https://github.com/m1stadev/PyIMG4/stargazers">
    <image src="https://img.shields.io/github/stars/m1stadev/PyIMG4">
  </a>
  <a href="https://github.com/m1stadev/PyIMG4">
    <image src="https://img.shields.io/tokei/lines/github/m1stadev/PyIMG4">
  </a>
    <br>
</p>

<p align="center">
A Python library/CLI tool for parsing Apple's <a href="https://www.theiphonewiki.com/wiki/IMG4_File_Format">IMG4 format</a>.
</p>

## Requirements
- Python 3.9 or higher

## Installation
- ```python3 -m pip install -U pyimg4```
- Local installation: `./install.sh`
    - Requires [Poetry](https://python-poetry.org)

## TODO
- Implement IMG4 creation
- Write CLI tool

## Support

For any questions/issues you have, [open an issue](https://github.com/m1stadev/PyIMG4/issues) or join my [Discord](https://m1sta.xyz/discord).
